==> v23.10.zip: bookstack/lang/lv/components.php <==
<?php
/**
 * Text used in custom JavaScript driven components.
 */
return [

    // Image Manager
    'image_select' => 'Attēla izvēle',
    'image_list' => 'Attēlu saraksts',
    'image_details' => 'Attēla dati',
    'image_upload' => 'Augšuplādēt attēlu',
    'image_intro' => 'Here you can select and manage images that have been previously uploaded to the system.',
    'image_intro_upload' => 'Upload a new image by dragging an image file into this window, or by using the "Upload Image" button above.',
    'image_all' => 'Visi',
    'image_all_title' => 'Skatīt visus attēlus',
    'image_book_title' => 'Apskatīt augšupielādētos attēlus šajā grāmatā',
    'image_page_title' => 'Apskatīt augšupielādētos attēlus šajā lapā',
    'image_search_hint' => 'Meklēt pēc attēla vārda',
    'image_uploaded' => 'Augšupielādēts :uploadedDate',
    'image_uploaded_by' => 'Uploaded by :userName',
    'image_uploaded_to' => 'Uploaded to :pageLink',
    'image_updated' => 'Updated :updateDate',
    'image_load_more' => 'Ielādēt vairāk',
    'image_image_name' => 'Attēla nosaukums',
    'image_delete_used' => 'Šis attēls ir ievietots zemāk redzamajās lapās.',
    'image_delete_confirm_text' => 'Vai tiešām vēlaties dzēst šo attēlu?',
    'image_select_image' => 'Atlasīt attēlu',
    'image_dropzone' => 'Ievilkt attēlu vai klikšķinat šeit, lai augšupielādētu',
    'image_dropzone_drop' => 'Drop images here to upload',
    'images_deleted' => 'Dzēstie attēli',
    'image_preview' => 'Attēla priekšskatījums',
    'image_upload_success' => 'Attēls ir veiksmīgi augšupielādēts',
    'image_update_success' => 'Attēlā informācija ir veiksmīgi atjunināta',
    'image_delete_success' => 'Attēls veiksmīgi dzēsts',
    'image_replace' => 'Nomainīt bildi',
    'image_replace_success' => 'Image file successfully updated',
    'image_rebuild_thumbs' => 'Regenerate Size Variations',
    'image_rebuild_thumbs_success' => 'Image size variations successfully rebuilt!',

    // Code Editor
    'code_editor' => 'Rediģēt kodu',
    'code_language' => 'Koda valoda',
    'code_content' => 'Koda teksts',
    'code_session_history' => 'Sesijas vēsture',
    'code_save' => 'Saglabāt kodu',
];

==> v23.12.1.zip: bookstack/lang/lv/components.php <==
<?php
/**
 * Text used in custom JavaScript driven components.
 */
return [

    // Image Manager
    'image_select' => 'Attēla izvēle',
    'image_list' => 'Attēlu saraksts',
    'image_details' => 'Attēla dati',
    'image_upload' => 'Augšuplādēt attēlu',
    'image_intro' => 'Šeit jūs varat izvēlēties un pārvaldīt attēlus, kuri iepriekš tika aplugšupielādēti sistēmā.',
    'image_intro_upload' => 'Upload a new image by dragging an image file into this window, or by using the "Upload Image" button above.',
    'image_all' => 'Visi',
    'image_all_title' => 'Skatīt visus attēlus',
    'image_book_title' => 'Apskatīt augšupielādētos attēlus šajā grāmatā',
    'image_page_title' => 'Apskatīt augšupielādētos attēlus šajā lapā',
    'image_search_hint' => 'Meklēt pēc attēla vārda',
    'image_uploaded' => 'Augšupielādēts :uploadedDate',
    'image_uploaded_by' => 'Uploaded by :userName',
    'image_uploaded_to' => 'Uploaded to :pageLink',
    'image_updated' => 'Updated :updateDate',
    'image_load_more' => 'Ielādēt vairāk',
    'image_image_name' => 'Attēla nosaukums',
    'image_delete_used' => 'Šis attēls ir ievietots zemāk redzamajās lapās.',
    'image_delete_confirm_text' => 'Vai tiešām vēlaties dzēst šo attēlu?',
    'image_select_image' => 'Atlasīt attēlu',
    'image_dropzone' => 'Ievilkt attēlu vai klikšķinat šeit, lai augšupielādētu',
    'image_dropzone_drop' => 'Drop images here to upload',
    'images_deleted' => 'Dzēstie attēli',
    'image_preview' => 'Attēla priekšskatījums',
    'image_upload_success' => 'Attēls ir veiksmīgi augšupielādēts',
    'image_update_success' => 'Attēlā informācija ir veiksmīgi atjunināta',
    'image_delete_success' => 'Attēls veiksmīgi dzēsts',
    'image_replace' => 'Nomainīt bildi',
    'image_replace_success' => 'Image file successfully updated',
    'image_rebuild_thumbs' => 'Regenerate Size Variations',
    'image_rebuild_thumbs_success' => 'Image size variations successfully rebuilt!',

    // Code Editor
    'code_editor' => 'Rediģēt kodu',
    'code_language' => 'Koda valoda',
    'code_content' => 'Koda teksts',
    'code_session_history' => 'Sesijas vēsture',
    'code_save' => 'Saglabāt kodu',
];
